@@ -51,13 +51,20 @@ from . import voucher
 from . import currency
 from . import order_line
 
-COUTRIES_MAP = dict(
+COUNTRIES_MAP = dict(
     ES = "Spain",
     PT = "Portugal"
 )
-""" Map that associated ISO alpha-2 country codes with
+""" Map that associates ISO alpha-2 country codes with
 their corresponding full text version to be used in Omni """
 
+GENDERS_MAP = dict(
+    Male = 1,
+    Female = 2
+)
+""" Map that associates the internal string based gender
+enumeration with the Omni's numeric one """
+
 class Order(bundle.Bundle):
 
     STATUS_S = dict(
@@ -1062,7 +1069,12 @@ class Order(bundle.Bundle):
 
         # retrieves via configuration the store from which the
         # sale is going to be performed (affects inventory)
-        store_id = appier.conf("OMNI_BOT_STORE", None)
+        store_id = appier.conf("OMNI_BOT_STORE", None, cast = int)
+
+        # gather using configuration the object ID of the services
+        # that represents the presence of the shipping and gift wrap
+        shipping_id = appier.conf("OMNI_BOT_SHIPPING", None, cast = int)
+        gift_wrap_id = appier.conf("OMNI_BOT_GIFT_WRAP", None, cast = int)
 
         # builds the "unique" description of the order from which
         # a duplicates are going to be avoided by explicit checking
@@ -1124,6 +1136,8 @@ class Order(bundle.Bundle):
             customer = dict(
                 name = self.account.first_name,
                 surname = self.account.last_name,
+                gender = GENDERS_MAP.get(self.account.gender, None),
+                birth_date = self.account.birth_date,
                 primary_contact_information = dict(
                     phone_number = self.billing_address.phone_number,
                     email = self.email
@@ -1132,7 +1146,7 @@ class Order(bundle.Bundle):
                     street_name = self.billing_address.address,
                     zip_code = self.billing_address.postal_code,
                     zip_code_name = self.billing_address.city,
-                    country = COUTRIES_MAP.get(self.billing_address.country, None)
+                    country = COUNTRIES_MAP.get(self.billing_address.country, None)
                 ),
                 tax_number = self.billing_address.vat_number,
                 observations = "created by Budy",
@@ -1153,19 +1167,33 @@ class Order(bundle.Bundle):
         sale_lines = []
         for line in self.lines:
             appier.verify(
-                "object_id" in line.product.meta,
+                "object_id" in line.merchandise.meta,
                 message = "Product was not imported from Omni, no object ID"
             )
             sale_line = dict(
-                merchandise = dict(object_id = line.product.meta["object_id"]),
+                merchandise = dict(object_id = line.merchandise.meta["object_id"]),
                 quantity = line.quantity
             )
             sale_lines.append(sale_line)
 
+        if self.shipping_cost > 0.0 and shipping_id:
+            sale_line = dict(
+                merchandise = dict(object_id = shipping_id),
+                quantity = 1
+            )
+            sale_lines.append(sale_line)
+
+        if self.gift_wrap and gift_wrap_id:
+            sale_line = dict(
+                merchandise = dict(object_id = gift_wrap_id),
+                quantity = 1
+            )
+            sale_lines.append(sale_line)
+
         primary_payment = dict(
             payment_lines = [
                 dict(
-                    payment_method = dict(_class = "CashPayment"),
+                    payment_method = dict(_class = "CardPayment"),
                     amount = dict(value = self.payable)
                 )
             ]
@@ -1193,7 +1221,10 @@ class Order(bundle.Bundle):
         # in case an invoice was requested then a proper money sale
         # slip must be generated for the target sale
         if invoice:
-            api.issue_money_sale_slip_sale(sale["object_id"])
+            api.issue_money_sale_slip_sale(
+                sale["object_id"],
+                metadata = dict(notes = "Budy order - %s" % self.reference)
+            )
 
         # updates the complete set of metadata related with the Omni
         # import operation so that the order is properly "marked" and
@@ -1201,6 +1232,7 @@ class Order(bundle.Bundle):
         self.meta.update(
             omni_timestamp = time.time(),
             omni_sale = sale["object_id"],
+            omni_sale_identifier = sale["identifier"],
             omni_url = api.base_url + "omni_sam/sales/%s" % sale["object_id"]
         )
         self.save()
